Class: RubyLLM::Agents::ExecutionDetail

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
app/models/ruby_llm/agents/execution_detail.rb

Overview

Stores large payload data for an execution (prompts, responses, tool calls, etc.)

Separated from Execution to keep the main table lean for analytics queries. Only created when there is detail data to store.

See Also: